{ config, pkgs, ... }:
{
  home = {
    username = "tbarnouin";
    stateVersion = "24.05";
    sessionPath = [
      "$HOME/.local/bin"
    ];
    file.".ssh/authorized_keys".text = ''
      ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIAxccGxdfOFXeEClqz3ULl94ubzaJnk4pUus+ek18G0B tbarnouin@nixos
    '';
  };
  programs = {
    git = {
      enable = true;
    };
    vim = {
      enable = true;
      plugins = with pkgs.vimPlugins; [
        vim-airline
        vim-airline-themes
        vim-bufferline
        vim-markdown
        markdown-preview-nvim
        tabular
      ];
      settings = {
        expandtab = true;
        ignorecase = true;
        smartcase = true;
        number = true;
        shiftwidth = 2;
        tabstop = 2;
      };
      extraConfig = ''
        set nocompatible
        filetype on
        filetype plugin on
        filetype indent on
        syntax on
        set nobackup
        set showcmd
        set showmode
        set showmatch
        set hlsearch
        set wrap
        set linebreak
        set textwidth=0
        set wrapmargin=0
        set scrolloff=15

        highlight ExtraWhitespace ctermbg=red guibg=red
        autocmd BufWritePre * :%s/\s\+$//e

        inoremap " ""<left>
        inoremap \' \'\'<left>
        inoremap ( ()<left>
        inoremap [ []<left>
        inoremap { {}<left>

        let g:vim_markdown_folding_disabled = 1
        let g:mkdp_auto_start = 1
        let g:mkdp_auto_close = 1
        let g:airline_theme='molokai'
      '';
    };
    zsh = {
      enable = true;
      shellAliases = {
        ll = "ls -l";
        lla = "ls -lah";
        terraform = "tofu";
        # Nixos
        update = "sudo nixos-rebuild switch";
        upgrade = "sudo nix-channel --update && sudo nixos-rebuild switch --upgrade";
        # Kitty
        #ssh = "kitten ssh";
        icat = "kitten icat";
      };
      oh-my-zsh = {
        enable = true;
        plugins =
          [
            "git"
            "terraform"
            "sudo"
            "docker"
            "pip"
            "python"
            "pyenv"
            "pipenv"
          ];
        theme = "bira";
      };
      initExtra = ''
        export MAMBA_EXE="/etc/profiles/per-user/tbarnouin/bin/micromamba";
        export MAMBA_ROOT_PREFIX="/home/tbarnouin/micromamba";
        __mamba_setup="$("$MAMBA_EXE" shell hook --shell zsh --prefix "$MAMBA_ROOT_PREFIX" 2> /dev/null)"
        if [ $? -eq 0 ]; then
            eval "$__mamba_setup"
        else
            if [ -f "/home/tbarnouin/micromamba/etc/profile.d/micromamba.sh" ]; then
                . "/home/tbarnouin/micromamba/etc/profile.d/micromamba.sh"
            else
                export  PATH="/home/tbarnouin/micromamba/bin:$PATH"
            fi
        fi
        unset __mamba_setup
      '';
    };
    tmux = {
      enable = true;
      mouse = true;
    };
  };
}
